@@ -44,8 +44,6 @@ pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
-pub mod event_request;
-pub use self::event_request::EventRequest;
 pub mod event_source;
 pub use self::event_source::EventSource;
 pub mod event_type;
@@ -222,6 +220,8 @@ pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
 pub mod polymorphic_event;
 pub use self::polymorphic_event::PolymorphicEvent;
+pub mod polymorphic_event_request;
+pub use self::polymorphic_event_request::PolymorphicEventRequest;
 pub mod print_job_event;
 pub use self::print_job_event::PrintJobEvent;
 pub mod print_job_event_request;
